@@ -1,9 +1,10 @@
 package Mojolicious::Plugin::DevexpressHelpers::Helpers;
-$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151410';
+$Mojolicious::Plugin::DevexpressHelpers::Helpers::VERSION = '0.151450';
 #ABSTRACT: Helpers for Devexpress controls are defined here
 use Modern::Perl;
 use Mojo::ByteStream;
 use MojoX::AlmostJSON qw(encode_json);
+use constant DEBUG => 0;
 
 sub out{
 	my $tag = shift;
@@ -36,28 +37,39 @@ sub new_id{
 }
 
 sub dxbind{
-	my ($c, $control, $id, $attrs, $extensions) = @_;
+	my ($c, $control, $id, $attrs, $extensions, $befores, $afters) = @_;
 	#should return html code to be associated to the control
-	my $binding = '$("#'.$id.'").'.$control.'({';
+	$befores //=[];
+	$afters  //=[];
+	#http://stackoverflow.com/questions/9930577/jquery-dot-in-id-selector
+	my $jquery_id = $id;
+	$jquery_id =~ s{\.}{\\\\.}g;
+	my $binding = '$("#'.$jquery_id.'").'.$control.'(';
     my @options;
-    for my $k ( sort keys %$attrs){
-		my $v = $attrs->{$k};
-		if(ref($v) eq 'SCALAR'){
-			#unref protected scalar
-			$v = $$v;
+	if (ref($attrs) eq 'HASH') {
+		$binding .= '{';
+		for my $k ( sort keys %$attrs){
+			my $v = $attrs->{$k};
+			if(ref($v) eq 'SCALAR'){
+				#unref protected scalar
+				$v = $$v;
+			}
+			elsif ($v!~/^\s*(?:function\s*\()/) {
+				$v =  encode_json $v;
+			}
+			push @options, "$k: $v";
 		}
-		elsif ($v!~/^\s*(?:function\s*\()/) {
-			$v =  encode_json $v;
-		}
-		push @options, "$k: $v";
-    }
+	}
+	else{
+		push @options, $attrs;
+	}
     $binding .= join ",\n", @options;
-    $binding .= '});';
+	$binding .= '}' if ref($attrs) eq 'HASH';
+    $binding .= ');';
 	#append some extensions (eg: dxdatagrid)
 	$binding .= join ";\n", @$extensions if defined $extensions;
 	$c->stash('dxHelper')->add_binding($binding);
-	#TODO: Possible extension: may add html attributs or sub content from special attributs
-	out '<div id="'.$id.'"></div>';
+	out join('',@$befores).'<div id="'.$id.'"></div>'.join('',@$afters);
 }
 
 
@@ -95,7 +107,7 @@ sub dxdatagrid{
 	my $id = delete($attrs->{id}) // new_id( $c, $attrs );
 	my @extensions;
 	#dxbind( $c, 'dxDataGrid' => $id => $attrs, [ $dataSource ]);
-	if (ref($attrs->{dataSource}) eq '') {
+	if ($attrs->{dataSource} && ref($attrs->{dataSource}) eq '') {
 		my $dataSource = delete $attrs->{dataSource};
 		#push @extensions, '$.getJSON("' . $dataSource . '",function(data){$("#'.$id.'").dxDataGrid({ dataSource: data });});';
 		#$attrs->{dataSource} = \'[]';	#protect string to be "stringified" within dxbind
@@ -103,6 +115,10 @@ sub dxdatagrid{
 		#\"" is to protect string to be "stringified" within dxbind
 		$attrs->{dataSource} = \"{store:{type:'odata',url:'$dataSource'}}";
 	}
+	if (exists $attrs->{options}) {
+		$attrs = $attrs->{options};
+	}
+	
 	dxbind( $c, 'dxDataGrid' => $id => $attrs, \@extensions);
 }
 
@@ -115,6 +131,30 @@ sub dxpopup{
 	dxbind( $c, 'dxPopup' => $id => $attrs );
 }
 
+sub dxtextbox{
+	my $c = shift;
+	my $attrs = parse_attributs( $c, [qw(id value label)], @_ );
+	my $id = delete($attrs->{id});
+	if (my $name = $id) {
+		$attrs->{attr}{name}=$name;
+	}
+	
+	$id //= new_id( $c, $attrs );
+
+	my (@before, @after);
+	if(my $label = delete($attrs->{label})){
+		push @before, '<div class="dx-field">';
+		push @before, '<div class="dx-field-label">'.$label.'</div>';
+		push @before, '<div class="dx-field-value">';
+		push @after, '</div>';
+		push @after, '</div>';
+	}
+	
+	dxbind( $c, 'dxTextBox' => $id => $attrs, undef, \@before, \@after );	
+}
+
+
+
 sub dxbuild {
 	my $c = shift;
 	my $dxhelper = $c->stash('dxHelper') or return;
@@ -148,7 +188,42 @@ sub required_assets{
 	return $results;
 }
 
+#Helper method to export without prepending a prefix
+my @without_prefix = qw( dxbuild required_assets require_asset );
 
+#Helper method to export with prepending a prefix
+my @with_prefix = qw( Button DataGrid Popup TextBox TextArea Switch
+	SelectBox NumberBox List DateBox CheckBox Calendar Box);
+sub register {
+	my ( $self, $app, $args ) = @_;
+	my $tp = $args->{tag_prefix};
+	
+	SUB_NO_PREFIX:
+	for my $subname ( @without_prefix ){
+		my $lc_name = lc $subname;
+		my $sub = __PACKAGE__->can( $lc_name );
+		unless($sub){
+			$app->log->debug(__PACKAGE__." helper '$lc_name' does not exists!");
+			next SUB_NO_PREFIX;
+		}
+		$app->helper( $lc_name => $sub );
+	}
+
+	SUB_WITH_PREFIX:
+	for my $subname ( @with_prefix ){
+		my $lc_name = lc $subname;
+		my $sub = __PACKAGE__->can( 'dx' . $lc_name );
+		unless($sub){
+			$app->log->debug(__PACKAGE__." helper 'dx$lc_name' does not exists!");
+			next SUB_WITH_PREFIX;
+		}
+		say STDERR "## adding helper '$tp$lc_name'" if DEBUG;
+		$app->helper( $tp . $lc_name => $sub );
+		say STDERR "## adding helper '$tp$subname'" if DEBUG and $args->{tag_camelcase};
+		$app->helper( $tp . $subname => $sub ) if $args->{tag_camelcase};
+	}
+	
+}
 
 1;
 
@@ -164,7 +239,7 @@ Mojolicious::Plugin::DevexpressHelpers::Helpers - Helpers for Devexpress control
 
 =head1 VERSION
 
-version 0.151410
+version 0.151450
 
 =head1 SUBROUTINES/METHODS
 
@@ -236,12 +311,31 @@ Internal usage
 	
 	%= dxdatagrid { id => myId, dataSource => '/products.json' }
 
+The following syntaxe allow to specify all options from a javascript object.
+B<Note: It will ignore all other options specified in the hash reference.>
+
+	%= dxdatagrid myId, { options => 'JSFrameWork.gridsOptions.myResource' }
+
 =head2 dxpopup C<[ $id, [ $title, [ $contentTemplate, ] ] ], [\%opts]>
 
 	%= dxpopup myPopupID => 'Popup Title', \q{function(contentElement){
 			contentElement.append('<p>Hello!</p>');
 		}};
 
+=head2 dxtextbox C<[ $id, [ $value, [ $label, ] ] ], [\%opts]>
+
+	%= dxtextbox 'name' => $value => 'Name: ', { placeHolder => 'Type a name' }
+
+=for comment TextArea
+Switch
+SelectBox
+NumberBox
+List
+DateBox
+CheckBox
+Calendar
+Box
+
 =head2 dxbuild
 
 Build the binding between jQuery and divs generated by plugin helpers such as dxbutton.
@@ -278,6 +372,10 @@ in your layout:
 Add assets that was specified by calls to require_asset.
 See require_asset for usage.
 
+=head2 register
+
+Register our helpers
+
 =head1 AUTHOR
 
 Nicolas Georges <xlat@cpan.org>
